@@ -243,7 +243,9 @@ void personal_gprs_mon_content_create (PersonalGprsMon *self)
 	if (gtk_icon_theme_has_icon (iconTheme, "personal-gprs-mon")) {
 		self->priv->titleImage = gtk_image_new_from_icon_name ("personal-gprs-mon", GTK_ICON_SIZE_BUTTON);
 	} else {
-		self->priv->titleImage = gtk_image_new_from_file ("/usr/share/icons/hicolor/64x64/hildon/personal-gprs-mon.png");
+		GdkPixbuf *pixbuf = gdk_pixbuf_new_from_file_at_scale ("/usr/share/icons/hicolor/64x64/hildon/personal-gprs-mon.png", 58, 58, TRUE, NULL);
+		self->priv->titleImage = gtk_image_new_from_pixbuf (pixbuf);
+		g_object_unref (pixbuf);
 	}
     self->priv->titleLabel = gtk_label_new ("Dataplan Monitor");
 	hildon_helper_set_logical_font (self->priv->titleLabel, "EmpSystemFont");
